@@ -29,7 +29,6 @@
 #include <list>
 #include <map>
 #include <memory>
-#include <optional>
 #include <set>
 #include <string>
 #include <utility>
@@ -39,7 +38,6 @@
 #include "modules/adminapi/common/common.h"
 #include "modules/adminapi/common/instance_pool.h"
 #include "modules/adminapi/common/metadata_management_mysql.h"
-#include "mysqlshdk/libs/db/session.h"
 #include "mysqlshdk/libs/mysql/group_replication.h"
 #include "mysqlshdk/libs/mysql/undo.h"
 #include "mysqlshdk/libs/mysql/utils.h"
@@ -214,6 +212,15 @@ class MetadataStorage {
    */
   void cleanup_for_cluster(Cluster_id cluster_id);
 
+  /**
+   * Deletes any dangling Clusters the ClusterSet's Metadata may have
+   *
+   * Ensures that any unrelated Cluster entries on the ClusterSet's Metadata are
+   * removed. Those can be resulting of failed actions, such as adding a new
+   * Replica Cluster.
+   */
+  void prune_clusterset_metadata(const Cluster_set_id &cs_id);
+
   Cluster_set_id create_cluster_set_record(
       Cluster_set_impl *cs, Cluster_id seed_cluster_id,
       shcore::Dictionary_t seed_attributes);
@@ -690,7 +697,7 @@ class MetadataStorage {
 
   template <typename... Args>
   inline std::shared_ptr<mysqlshdk::db::IResult> execute_sqlf(
-      const std::string &sql, const Args &... args) const {
+      const std::string &sql, const Args &...args) const {
     return execute_sql(shcore::sqlformat(sql, args...));
   }
 
