@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2015, 2022, Oracle and/or its affiliates.
+ * Copyright (c) 2015, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -287,6 +289,14 @@ static PyTypeObject Array_object_type = {
     0  // tp_print
 #endif
 #endif
+#if PY_VERSION_HEX >= 0x030C0000
+    ,
+    0  // tp_watched
+#endif
+#if PY_VERSION_HEX >= 0x030D0000
+    ,
+    0  // tp_versions_used
+#endif
 };
 
 #if PY_VERSION_HEX >= 0x03080000 && PY_VERSION_HEX < 0x03090000
@@ -452,6 +462,14 @@ static PyTypeObject Array_object_iterator_type = {
     0  // tp_print
 #endif
 #endif
+#if PY_VERSION_HEX >= 0x030C0000
+    ,
+    0  // tp_watched
+#endif
+#if PY_VERSION_HEX >= 0x030D0000
+    ,
+    0  // tp_versions_used
+#endif
 };
 
 #if PY_VERSION_HEX >= 0x03080000 && PY_VERSION_HEX < 0x03090000
@@ -600,6 +618,14 @@ static PyTypeObject Array_object_reverse_iterator_type = {
     0  // tp_print
 #endif
 #endif
+#if PY_VERSION_HEX >= 0x030C0000
+    ,
+    0  // tp_watched
+#endif
+#if PY_VERSION_HEX >= 0x030D0000
+    ,
+    0  // tp_versions_used
+#endif
 };
 
 #if PY_VERSION_HEX >= 0x03080000 && PY_VERSION_HEX < 0x03090000
@@ -768,8 +794,15 @@ void replace_list_concat() {
     Array_object_type.tp_base->tp_as_sequence->sq_concat = new_list_concat;
 
     // replace list.__add__ as well
-    const auto add = (PyWrapperDescrObject *)PyDict_GetItemString(
-        Array_object_type.tp_base->tp_dict, "__add__");
+    const auto dict =
+#if PY_VERSION_HEX >= 0x030C0000
+        PyType_GetDict(Array_object_type.tp_base)
+#else
+        Array_object_type.tp_base->tp_dict
+#endif
+        ;
+    const auto add =
+        (PyWrapperDescrObject *)PyDict_GetItemString(dict, "__add__");
 
     assert(add);
     assert((binaryfunc)add->d_wrapped == old_list_concat);
@@ -1519,7 +1552,25 @@ int ao_init(Array_object *self, PyObject *args, PyObject *kw) {
     return -1;
   }
 
-  if (!_PyArg_NoKeywords("List", kw)) {
+  static constexpr auto expect_no_keywords = [](PyObject *kwargs) {
+    if (!kwargs) {
+      return true;
+    }
+
+    if (!PyDict_CheckExact(kwargs)) {
+      PyErr_BadInternalCall();
+      return false;
+    }
+
+    if (0 == PyDict_GET_SIZE(kwargs)) {
+      return true;
+    }
+
+    PyErr_SetString(PyExc_TypeError, "List() takes no keyword arguments");
+    return false;
+  };
+
+  if (!expect_no_keywords(kw)) {
     return -1;
   }
 
