@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2017, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2017, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -188,6 +190,11 @@ TEST_F(MySQL_upgrade_check_test, reserved_keywords) {
   EXPECT_NE(nullptr, check->get_doc_link());
   EXPECT_NO_ISSUES(check.get());
 
+  auto drop_database = [&]() {
+    ASSERT_NO_THROW(session->execute("drop database if exists grouping;"));
+  };
+  auto on_exit = shcore::on_leave_scope(drop_database);
+
   PrepareTestDatabase("grouping");
   ASSERT_NO_THROW(
       session->execute("create table System(JSON_TABLE integer, cube int);"));
@@ -206,11 +213,14 @@ TEST_F(MySQL_upgrade_check_test, reserved_keywords) {
   ASSERT_NO_THROW(
       session->execute("CREATE FUNCTION full (s CHAR(20)) RETURNS CHAR(50) "
                        "DETERMINISTIC RETURN CONCAT('Hello, ',s,'!');"));
+  ASSERT_NO_THROW(session->execute(
+      "CREATE FUNCTION inteRsect (s CHAR(20)) RETURNS CHAR(50) "
+      "DETERMINISTIC RETURN CONCAT('Hello, ',s,'!');"));
   ASSERT_NO_THROW(session->execute(
       "CREATE EVENT LEAD ON SCHEDULE AT CURRENT_TIMESTAMP + INTERVAL 1 "
       "HOUR DO UPDATE System SET JSON_TABLE = JSON_TABLE + 1;"));
 
-  EXPECT_ISSUES(check.get(), 13);
+  EXPECT_ISSUES(check.get(), 14);
   EXPECT_ISSUE(issues[0], "grouping");
   EXPECT_ISSUE(issues[1], "grouping", "System");
   EXPECT_ISSUE(issues[2], "grouping", "NTile", "JSON_TABLE");
@@ -222,8 +232,9 @@ TEST_F(MySQL_upgrade_check_test, reserved_keywords) {
   EXPECT_ISSUE(issues[8], "grouping", "NTile");
   EXPECT_ISSUE(issues[9], "grouping", "Array");
   EXPECT_ISSUE(issues[10], "grouping", "full");
-  EXPECT_ISSUE(issues[11], "grouping", "rows");
-  EXPECT_ISSUE(issues[12], "grouping", "LEAD");
+  EXPECT_ISSUE(issues[11], "grouping", "inteRsect");
+  EXPECT_ISSUE(issues[12], "grouping", "rows");
+  EXPECT_ISSUE(issues[13], "grouping", "LEAD");
 
   check = Sql_upgrade_check::get_reserved_keywords_check(
       upgrade_info(Version(5, 7, 0), Version(8, 0, 30)));
@@ -236,6 +247,35 @@ TEST_F(MySQL_upgrade_check_test, reserved_keywords) {
       upgrade_info(Version(5, 7, 0), Version(8, 0, 11)));
   ASSERT_NO_THROW(issues = check->run(session, info));
   ASSERT_EQ(10, issues.size());
+
+  drop_database();
+
+  auto on_exit2 = shcore::on_leave_scope([&]() {
+    ASSERT_NO_THROW(session->execute("drop database if exists db_test;"));
+  });
+  PrepareTestDatabase("db_test");
+
+  ASSERT_NO_THROW(session->execute("create table `array`(id int);"));
+  ASSERT_NO_THROW(session->execute("create table `full`(id int);"));
+  ASSERT_NO_THROW(session->execute("create table `intersect`(id int);"));
+  ASSERT_NO_THROW(session->execute("create table `lateral`(id int);"));
+  ASSERT_NO_THROW(session->execute("create table `member`(id int);"));
+
+  check = Sql_upgrade_check::get_reserved_keywords_check(
+      upgrade_info(Version(5, 7, 44), Version(8, 0, 35)));
+
+  EXPECT_ISSUES(check.get(), 5);
+
+  EXPECT_EQ(issues[0].schema, "db_test");
+  EXPECT_EQ(issues[0].table, "array");
+  EXPECT_EQ(issues[1].schema, "db_test");
+  EXPECT_EQ(issues[1].table, "full");
+  EXPECT_EQ(issues[2].schema, "db_test");
+  EXPECT_EQ(issues[2].table, "intersect");
+  EXPECT_EQ(issues[3].schema, "db_test");
+  EXPECT_EQ(issues[3].table, "lateral");
+  EXPECT_EQ(issues[4].schema, "db_test");
+  EXPECT_EQ(issues[4].table, "member");
 }
 
 TEST_F(MySQL_upgrade_check_test, syntax_check) {
@@ -987,8 +1027,12 @@ TEST_F(MySQL_upgrade_check_test, zero_dates_check) {
 
   PrepareTestDatabase("mysql_zero_dates_check_test");
   auto check = Sql_upgrade_check::get_zero_dates_check();
-  EXPECT_EQ(0, strcmp("https://lefred.be/content/mysql-8-0-and-wrong-dates/",
-                      check->get_doc_link()));
+  EXPECT_STREQ(
+      "https://dev.mysql.com/doc/refman/8.0/en/datetime.html\nhttps://"
+      "dev.mysql.com/doc/refman/8.0/en/"
+      "sql-mode.html#sqlmode_no_zero_date\nhttps://dev.mysql.com/doc/refman/"
+      "8.0/en/sql-mode.html#sqlmode_no_zero_in_date",
+      check->get_doc_link());
   EXPECT_NO_ISSUES(check.get());
 
   ASSERT_NO_THROW(
@@ -1673,4 +1717,98 @@ TEST_F(MySQL_upgrade_check_test, empty_dot_table_syntax_check) {
   ASSERT_NO_THROW(session->execute("DROP SCHEMA IF EXISTS dot_table_test;"));
 }
 
+TEST_F(MySQL_upgrade_check_test, invalid_engine_foreign_key_check) {
+  SKIP_IF_NOT_5_7_UP_TO(Version(8, 0, 0));
+
+  PrepareTestDatabase("inv_eng_db");
+
+  ASSERT_NO_THROW(session->execute("SET SESSION foreign_key_checks = OFF;"));
+
+  ASSERT_NO_THROW(session->execute(R"(
+  CREATE TABLE `testtable` (
+  `column_idColumn` int NOT NULL,
+      KEY `fk_TestTable_SecondTable` (`column_idColumn`),
+      CONSTRAINT `const_TestTable_SecondTable` FOREIGN
+          KEY(`column_idColumn`)
+              REFERENCES `secondtable` (`idColumn`) ON DELETE NO ACTION)
+      ENGINE = InnoDB;)"));
+
+  ASSERT_NO_THROW(session->execute(R"(CREATE TABLE `secondtable` (
+  `idColumn` int NOT NULL, PRIMARY KEY(`idColumn`)) ENGINE = InnoDB;)"));
+
+  const auto check = Sql_upgrade_check::get_invalid_engine_foreign_key_check();
+  EXPECT_NO_ISSUES(check.get());
+
+  ASSERT_NO_THROW(session->execute("DROP TABLE secondtable;"));
+
+  ASSERT_NO_THROW(session->execute(R"(CREATE TABLE `secondtable` (
+  `idColumn` int NOT NULL, PRIMARY KEY(`idColumn`)) ENGINE = MyISAM;)"));
+
+  EXPECT_ISSUES(check.get(), 1);
+
+  EXPECT_EQ("inv_eng_db", issues[0].schema);
+  EXPECT_EQ("testtable", issues[0].table);
+  EXPECT_EQ("column_idColumn", issues[0].column);
+  EXPECT_EQ(
+      "column has invalid foreign key to column 'idColumn' from table "
+      "'inv_eng_db/secondtable' that is from a different database engine "
+      "(MyISAM).",
+      issues[0].description);
+
+  ASSERT_NO_THROW(session->execute("SET SESSION foreign_key_checks = ON;"));
+  ASSERT_NO_THROW(session->execute("DROP SCHEMA IF EXISTS inv_eng_db;"));
+}
+
+TEST_F(MySQL_upgrade_check_test, no_database_selected_corrupted_check) {
+  SKIP_IF_NOT_5_7_UP_TO(Version(5, 7, 40));
+
+  PrepareTestDatabase("test");
+
+  ASSERT_NO_THROW(
+      session->execute("create table test_table (test_column INT);"));
+  ASSERT_NO_THROW(session->execute(
+      "create view test_view as select `t`.`test_column` from (select "
+      "`test`.`test_table`.`test_column` as `test_column` from "
+      "`test`.`test_table` group by `test`.`test_table`.`test_column`) t;"));
+
+  // clear current USE to null
+  ASSERT_NO_THROW(session->execute("create database temp_db;"));
+  ASSERT_NO_THROW(session->execute("use temp_db;"));
+  ASSERT_NO_THROW(session->execute("drop database temp_db;"));
+
+  const auto check = std::make_unique<Check_table_command>();
+  EXPECT_ISSUES(check.get(), 2);
+  EXPECT_EQ("test", issues[0].schema);
+  EXPECT_EQ("test_view", issues[0].table);
+  EXPECT_EQ("No database selected", issues[0].description);
+  EXPECT_EQ("test", issues[1].schema);
+  EXPECT_EQ("test_view", issues[1].table);
+  EXPECT_EQ("Corrupt", issues[1].description);
+
+  ASSERT_NO_THROW(session->execute("use mysql;"));
+
+  EXPECT_NO_ISSUES(check.get());
+
+  // clear current USE to null
+  ASSERT_NO_THROW(session->execute("create database temp_db;"));
+  ASSERT_NO_THROW(session->execute("use temp_db;"));
+  ASSERT_NO_THROW(session->execute("drop database temp_db;"));
+
+  auto cfg = Upgrade_check_config(Upgrade_check_options());
+  cfg.set_user_privileges(nullptr);
+  cfg.set_session(session);
+  cfg.set_issue_filter([](const Upgrade_issue &issue) {
+    if (issue.schema != "test") return false;
+    if (issue.table != "test_view") return false;
+    if (issue.description != "No database selected" &&
+        issue.description != "Corrupt")
+      return false;
+    return true;
+  });
+
+  EXPECT_TRUE(check_for_upgrade(cfg));
+
+  ASSERT_NO_THROW(session->execute("drop schema if exists test;"));
+}
+
 }  // namespace mysqlsh
